from setuptools import setup

setup(name='distributions_AWS_Col_2020',
      version='0.1',
      description='Gaussian distributions_AWS_Col_2020',
      packages=['distributions_AWS_Col_2020'],
      Author = 'Michael Levkovsky',
      Author_email = 'levkos@hotmail.com',
      zip_safe=False)
     
    
